@@ -1,25 +1,27 @@
 from .cps import (
+    CPS_2019,
     CPS_2020,
     CPS_2021,
     CPS_2022,
-    CPS_2023,
     RawCPS_2020,
     RawCPS_2021,
     RawCPS_2022,
-    EnhancedCPS_2023,
-    PUFExtendedCPS_2023,
-    CalibratedCPS_2023,
+    EnhancedCPS_2022,
+    CalibratedPUFExtendedCPS_2022,
 )
 
+from .puf import PUF_2022, PUF_2015
+
 from .poverty_tracker.poverty_tracker import PovertyTracker
 
 DATASETS = [
+    CPS_2019,
     CPS_2020,
     CPS_2021,
     CPS_2022,
-    CPS_2023,
-    EnhancedCPS_2023,
-    PUFExtendedCPS_2023,
-    CalibratedCPS_2023,
+    EnhancedCPS_2022,
+    CalibratedPUFExtendedCPS_2022,
     PovertyTracker,
+    PUF_2022,
+    PUF_2015,
 ]
