@@ -1,7 +1,10 @@
 import logging
 from policyengine_core.data import Dataset
+from policyengine_us.data.storage import STORAGE_FOLDER
 import h5py
 from policyengine_us.data.datasets.cps.raw_cps import (
+    RawCPS_2018,
+    RawCPS_2019,
     RawCPS_2020,
     RawCPS_2021,
     RawCPS_2022,
@@ -21,6 +24,7 @@ class CPS(Dataset):
     name = "cps"
     label = "CPS"
     raw_cps: Type[RawCPS] = None
+    previous_year_raw_cps: Type[RawCPS] = None
     data_format = Dataset.ARRAYS
 
     def generate(self):
@@ -28,7 +32,7 @@ class CPS(Dataset):
         Technical documentation and codebook here: https://www2.census.gov/programs-surveys/cps/techdocs/cpsmar21.pdf
         """
 
-        raw_data = self.raw_cps().load()
+        raw_data = self.raw_cps(require=True).load()
         cps = h5py.File(self.file_path, mode="w")
 
         ENTITIES = ("person", "tax_unit", "family", "spm_unit", "household")
@@ -39,6 +43,7 @@ class CPS(Dataset):
         add_id_variables(cps, person, tax_unit, family, spm_unit, household)
         add_personal_variables(cps, person)
         add_personal_income_variables(cps, person, self.raw_cps.time_period)
+        add_previous_year_income(self, cps)
         add_spm_variables(cps, spm_unit)
         add_household_variables(cps, household)
 
@@ -46,7 +51,6 @@ class CPS(Dataset):
         cps.close()
 
         cps = h5py.File(self.file_path, mode="a")
-        add_silver_plan_cost(self, cps, 2022)
         cps.close()
 
 
@@ -161,7 +165,7 @@ def add_personal_variables(cps: h5py.File, person: DataFrame) -> None:
     DISABILITY_FLAGS = [
         "PEDIS" + i for i in ["DRS", "EAR", "EYE", "OUT", "PHY", "REM"]
     ]
-    cps["is_ssi_disabled"] = (person[DISABILITY_FLAGS] == 1).any(axis=1)
+    cps["is_disabled"] = (person[DISABILITY_FLAGS] == 1).any(axis=1)
 
     def children_per_parent(col: str) -> pd.DataFrame:
         """Calculate number of children in the household using parental
@@ -201,6 +205,8 @@ def add_personal_variables(cps: h5py.File, person: DataFrame) -> None:
 
     cps["is_widowed"] = person.A_MARITL == 4
     cps["is_separated"] = person.A_MARITL == 6
+    # High school or college/university enrollment status.
+    cps["is_full_time_college_student"] = person.A_HSCOL == 2
 
 
 def add_personal_income_variables(
@@ -215,7 +221,8 @@ def add_personal_income_variables(
     """
     # Get income imputation parameters.
     yamlfilename = os.path.join(
-        os.path.abspath(os.path.dirname(__file__)), "income_parameters.yaml"
+        os.path.abspath(os.path.dirname(__file__)),
+        "imputation_parameters.yaml",
     )
     with open(yamlfilename, "r", encoding="utf-8") as yamlfile:
         p = yaml.safe_load(yamlfile)
@@ -223,19 +230,22 @@ def add_personal_income_variables(
 
     # Assign CPS variables.
     cps["employment_income"] = person.WSAL_VAL
+
+    cps["weekly_hours_worked"] = person.HRSWK * person.WKSWORK / 52
+
     cps["taxable_interest_income"] = person.INT_VAL * (
-        p["taxable_interest_fraction"][year]
+        p["taxable_interest_fraction"]
     )
     cps["tax_exempt_interest_income"] = person.INT_VAL * (
-        1 - p["taxable_interest_fraction"][year]
+        1 - p["taxable_interest_fraction"]
     )
     cps["self_employment_income"] = person.SEMP_VAL
     cps["farm_income"] = person.FRSE_VAL
     cps["qualified_dividend_income"] = person.DIV_VAL * (
-        p["qualified_dividend_fraction"][year]
+        p["qualified_dividend_fraction"]
     )
     cps["non_qualified_dividend_income"] = person.DIV_VAL * (
-        1 - p["qualified_dividend_fraction"][year]
+        1 - p["qualified_dividend_fraction"]
     )
     cps["rental_income"] = person.RNT_VAL
     # Assign Social Security retirement benefits if at least 62.
@@ -247,15 +257,62 @@ def add_personal_income_variables(
     cps["social_security_disability"] = (
         person.SS_VAL - cps["social_security_retirement"]
     )
+    # Provide placeholders for other Social Security inputs to avoid creating
+    # NaNs as they're uprated.
+    cps["social_security_dependents"] = np.zeros_like(
+        cps["social_security_retirement"]
+    )
+    cps["social_security_survivors"] = np.zeros_like(
+        cps["social_security_retirement"]
+    )
     cps["unemployment_compensation"] = person.UC_VAL
     # Add pensions and annuities.
     cps_pensions = person.PNSN_VAL + person.ANN_VAL
-    cps["taxable_pension_income"] = cps_pensions * (
-        p["taxable_pension_fraction"][year]
+    # Assume a constant fraction of pension income is taxable.
+    cps["taxable_private_pension_income"] = (
+        cps_pensions * p["taxable_pension_fraction"]
     )
-    cps["tax_exempt_pension_income"] = cps_pensions * (
-        1 - p["taxable_pension_fraction"][year]
+    cps["tax_exempt_private_pension_income"] = cps_pensions * (
+        1 - p["taxable_pension_fraction"]
     )
+    # Retirement account distributions.
+    RETIREMENT_CODES = {
+        1: "401k",
+        2: "403b",
+        3: "roth_ira",
+        4: "regular_ira",
+        5: "keogh",
+        6: "sep",  # Simplified Employee Pension plan
+        7: "other_type_retirement_account",
+    }
+    for code, description in RETIREMENT_CODES.items():
+        tmp = 0
+        # The ASEC splits distributions across four variable pairs.
+        for i in ["1", "2", "1_YNG", "2_YNG"]:
+            tmp += (person["DST_SC" + i] == code) * person["DST_VAL" + i]
+        cps[f"{description}_distributions"] = tmp
+    # Allocate retirement distributions by taxability.
+    for source_with_taxable_fraction in ["401k", "403b", "sep"]:
+        cps[f"taxable_{source_with_taxable_fraction}_distributions"] = (
+            cps[f"{source_with_taxable_fraction}_distributions"][...]
+            * p[
+                f"taxable_{source_with_taxable_fraction}_distribution_fraction"
+            ]
+        )
+        cps[f"tax_exempt_{source_with_taxable_fraction}_distributions"] = cps[
+            f"{source_with_taxable_fraction}_distributions"
+        ][...] * (
+            1
+            - p[
+                f"taxable_{source_with_taxable_fraction}_distribution_fraction"
+            ]
+        )
+        del cps[f"{source_with_taxable_fraction}_distributions"]
+
+    # Assume all regular IRA distributions are taxable,
+    # and all Roth IRA distributions are not.
+    cps["taxable_ira_distributions"] = cps["regular_ira_distributions"]
+    cps["tax_exempt_ira_distributions"] = cps["roth_ira_distributions"]
     # Other income (OI_VAL) is a catch-all for all other income sources.
     # The code for alimony income is 20.
     cps["alimony_income"] = (person.OI_OFF == 20) * person.OI_VAL
@@ -266,12 +323,76 @@ def add_personal_income_variables(
     # They could also include General Assistance.
     cps["tanf_reported"] = person.PAW_VAL
     cps["ssi_reported"] = person.SSI_VAL
-    cps["pension_contributions"] = person.RETCB_VAL
+    # Assume all retirement contributions are traditional 401(k) for now.
+    # Procedure for allocating retirement contributions:
+    # 1) If they report any self-employment income, allocate entirely to
+    #    self-employed pension contributions.
+    # 2) If they report any wage and salary income, allocate in this order:
+    #    a) Traditional 401(k) contributions up to to limit
+    #    b) Roth 401(k) contributions up to the limit
+    #    c) IRA contributions up to the limit, split according to administrative fractions
+    #    d) Other retirement contributions
+    # Disregard reported pension contributions from people who report neither wage and salary
+    # nor self-employment income.
+    # Assume no 403(b) or 457 contributions for now.
+    LIMIT_401K_2022 = 20_500
+    LIMIT_401K_CATCH_UP_2022 = 6_500
+    LIMIT_IRA_2022 = 6_000
+    LIMIT_IRA_CATCH_UP_2022 = 1_000
+    CATCH_UP_AGE_2022 = 50
+    retirement_contributions = person.RETCB_VAL
+    cps["self_employed_pension_contributions"] = np.where(
+        person.SEMP_VAL > 0, retirement_contributions, 0
+    )
+    remaining_retirement_contributions = np.maximum(
+        retirement_contributions - cps["self_employed_pension_contributions"],
+        0,
+    )
+    # Compute the 401(k) limit for the person's age.
+    catch_up_eligible = person.A_AGE >= CATCH_UP_AGE_2022
+    limit_401k = LIMIT_401K_2022 + catch_up_eligible * LIMIT_401K_CATCH_UP_2022
+    limit_ira = LIMIT_IRA_2022 + catch_up_eligible * LIMIT_IRA_CATCH_UP_2022
+    cps["traditional_401k_contributions"] = np.where(
+        person.WSAL_VAL > 0,
+        np.minimum(remaining_retirement_contributions, limit_401k),
+        0,
+    )
+    remaining_retirement_contributions = np.maximum(
+        remaining_retirement_contributions
+        - cps["traditional_401k_contributions"],
+        0,
+    )
+    cps["roth_401k_contributions"] = np.where(
+        person.WSAL_VAL > 0,
+        np.minimum(remaining_retirement_contributions, limit_401k),
+        0,
+    )
+    remaining_retirement_contributions = np.maximum(
+        remaining_retirement_contributions - cps["roth_401k_contributions"],
+        0,
+    )
+    cps["traditional_ira_contributions"] = np.where(
+        person.WSAL_VAL > 0,
+        np.minimum(remaining_retirement_contributions, limit_ira),
+        0,
+    )
+    remaining_retirement_contributions = np.maximum(
+        remaining_retirement_contributions
+        - cps["traditional_ira_contributions"],
+        0,
+    )
+    roth_ira_limit = limit_ira - cps["traditional_ira_contributions"]
+    cps["roth_ira_contributions"] = np.where(
+        person.WSAL_VAL > 0,
+        np.minimum(remaining_retirement_contributions, roth_ira_limit),
+        0,
+    )
+    # Allocate capital gains into long-term and short-term based on aggregate split.
     cps["long_term_capital_gains"] = person.CAP_VAL * (
-        p["long_term_capgain_fraction"][year]
+        p["long_term_capgain_fraction"]
     )
     cps["short_term_capital_gains"] = person.CAP_VAL * (
-        1 - p["long_term_capgain_fraction"][year]
+        1 - p["long_term_capgain_fraction"]
     )
     cps["receives_wic"] = person.WICYN == 1
     cps["veterans_benefits"] = person.VET_VAL
@@ -302,18 +423,21 @@ def add_spm_variables(cps: h5py.File, spm_unit: DataFrame) -> None:
         free_school_meals_reported="SPM_SCHLUNCH",
         spm_unit_energy_subsidy_reported="SPM_ENGVAL",
         spm_unit_wic_reported="SPM_WICVAL",
+        spm_unit_broadband_subsidy_reported="SPM_BBSUBVAL",
         spm_unit_payroll_tax_reported="SPM_FICA",
         spm_unit_federal_tax_reported="SPM_FEDTAX",
+        # State tax includes refundable credits.
         spm_unit_state_tax_reported="SPM_STTAX",
-        spm_unit_work_childcare_expenses="SPM_CAPWKCCXPNS",
+        spm_unit_capped_work_childcare_expenses="SPM_CAPWKCCXPNS",
         spm_unit_medical_expenses="SPM_MEDXPNS",
         spm_unit_spm_threshold="SPM_POVTHRESHOLD",
         spm_unit_net_income_reported="SPM_RESOURCES",
-        childcare_expenses="SPM_CHILDCAREXPNS",
+        spm_unit_pre_subsidy_childcare_expenses="SPM_CHILDCAREXPNS",
     )
 
     for openfisca_variable, asec_variable in SPM_RENAMES.items():
-        cps[openfisca_variable] = spm_unit[asec_variable]
+        if asec_variable in spm_unit.columns:
+            cps[openfisca_variable] = spm_unit[asec_variable]
 
     cps["reduced_price_school_meals_reported"] = (
         cps["free_school_meals_reported"][...] * 0
@@ -343,6 +467,77 @@ def add_household_variables(cps: h5py.File, household: DataFrame) -> None:
     cps["in_nyc"] = np.isin(state_county_fips, nyc_full_county_fips)
 
 
+def add_previous_year_income(self, cps: h5py.File) -> None:
+    if self.previous_year_raw_cps is None:
+        print(
+            "No previous year data available for this dataset, skipping previous year income imputation."
+        )
+        return
+
+    from survey_enhance.impute import Imputation
+
+    cps_current_year_data = self.raw_cps(require=True).load()
+    cps_previous_year_data = self.previous_year_raw_cps(require=True).load()
+    cps_previous_year = cps_previous_year_data.person.set_index(
+        cps_previous_year_data.person.PERIDNUM
+    )
+    cps_current_year = cps_current_year_data.person.set_index(
+        cps_current_year_data.person.PERIDNUM
+    )
+
+    previous_year_data = cps_previous_year[
+        ["WSAL_VAL", "SEMP_VAL", "I_ERNVAL", "I_SEVAL"]
+    ].rename(
+        {
+            "WSAL_VAL": "employment_income_last_year",
+            "SEMP_VAL": "self_employment_income_last_year",
+        },
+        axis=1,
+    )
+
+    previous_year_data = previous_year_data[
+        (previous_year_data.I_ERNVAL == 0) & (previous_year_data.I_SEVAL == 0)
+    ]
+
+    previous_year_data.drop(["I_ERNVAL", "I_SEVAL"], axis=1, inplace=True)
+
+    joined_data = cps_current_year.join(previous_year_data)[
+        [
+            "employment_income_last_year",
+            "self_employment_income_last_year",
+            "I_ERNVAL",
+            "I_SEVAL",
+        ]
+    ]
+    joined_data["previous_year_income_available"] = (
+        ~joined_data.employment_income_last_year.isna()
+        & ~joined_data.self_employment_income_last_year.isna()
+        & (joined_data.I_ERNVAL == 0)
+        & (joined_data.I_SEVAL == 0)
+    )
+    joined_data = joined_data.fillna(-1).drop(["I_ERNVAL", "I_SEVAL"], axis=1)
+
+    # CPS already ordered by PERIDNUM, so the join wouldn't change the order.
+    cps["employment_income_last_year"] = joined_data[
+        "employment_income_last_year"
+    ].values
+    cps["self_employment_income_last_year"] = joined_data[
+        "self_employment_income_last_year"
+    ].values
+    cps["previous_year_income_available"] = joined_data[
+        "previous_year_income_available"
+    ].values
+
+
+class CPS_2019(CPS):
+    name = "cps_2019"
+    label = "CPS 2019"
+    raw_cps = RawCPS_2019
+    previous_year_raw_cps = RawCPS_2018
+    file_path = STORAGE_FOLDER / "cps_2019.h5"
+    time_period = 2019
+
+
 class CPS_2020(CPS):
     name = "cps_2020"
     label = "CPS 2020"
@@ -363,16 +558,7 @@ class CPS_2022(CPS):
     name = "cps_2022"
     label = "CPS 2022"
     raw_cps = RawCPS_2022
+    previous_year_raw_cps = RawCPS_2021
     file_path = STORAGE_FOLDER / "cps_2022.h5"
     time_period = 2022
-    # url = None
-
-
-CPS_2023 = UpratedCPS.from_dataset(
-    CPS_2022,
-    2023,
-    "cps_2023",
-    "CPS 2023",
-    STORAGE_FOLDER / "cps_2023.h5",
-    new_url="release://policyengine/policyengine-us/cps-2023/cps_2023.h5",
-)
+    url = "release://policyengine/policyengine-us/cps-2022/cps_2022.h5"
