@@ -33,5 +33,10 @@ simulation = SimulationBuilder().build_from_dict(system, DEFAULT_SITUATION)
 
 @pytest.mark.parametrize("variable", system.variables)
 def test_variable(variable: str) -> None:
-    if variable not in EXEMPTIONS:
+    requires_computation_after = system.variables[
+        variable
+    ].requires_computation_after
+    if requires_computation_after:
+        simulation.calculate(requires_computation_after, 2022)
+    elif variable not in EXEMPTIONS:
         simulation.calculate(variable, 2022)
