@@ -10,4 +10,4 @@ class hud_annual_income(Variable):
     definition_period = YEAR
     reference = "https://www.law.cornell.edu/cfr/text/24/5.609"
 
-    adds = ["market_income"]
+    adds = ["market_income", "social_security", "ssi", "tanf"]
