@@ -11,10 +11,5 @@ class elderly_disabled_credit(Variable):
     reference = "https://www.law.cornell.edu/uscode/text/26/22"
 
     def formula(tax_unit, period, parameters):
-        elderly_disabled = parameters(
-            period
-        ).gov.irs.credits.elderly_or_disabled
-        return elderly_disabled.rate * tax_unit("section_22_income", period)
-
-
-c07200 = variable_alias("c07200", elderly_disabled_credit)
+        p = parameters(period).gov.irs.credits.elderly_or_disabled
+        return p.rate * tax_unit("section_22_income", period)
