@@ -8,3 +8,6 @@ class al_income_tax(Variable):
     unit = USD
     definition_period = YEAR
     defined_for = StateCode.AL
+
+    adds = ["al_income_tax_before_refundable_credits"]
+    subtracts = ["al_refundable_credits"]
