@@ -12,5 +12,5 @@ class ca_agi(Variable):
         "https://www.ftb.ca.gov/forms/2022/2022-540.pdf"
     )
     defined_for = StateCode.CA
-    adds = ["adjusted_gross_income", "ca_agi_additions"]
+    adds = ["adjusted_gross_income", "ca_additions"]
     subtracts = ["ca_agi_subtractions"]
