@@ -8,10 +8,13 @@ class co_ccap_subsidy(Variable):
     unit = USD
     definition_period = MONTH
     defined_for = "co_ccap_eligible"
+    exhaustive_parameter_dependencies = "gov.states.co.ccap"
 
     def formula(spm_unit, period, parameters):
         expenses = add(
-            spm_unit, period, ["childcare_expenses", "after_school_expenses"]
+            spm_unit,
+            period,
+            ["pre_subsidy_childcare_expenses", "after_school_expenses"],
         )
         parent_fee = spm_unit("co_ccap_parent_fee", period)
         return max_(expenses - parent_fee, 0)
