@@ -3,7 +3,7 @@ from policyengine_us.model_api import *
 
 class de_subtractions(Variable):
     value_type = float
-    entity = TaxUnit
+    entity = Person
     label = "Delaware subtractions"
     unit = USD
     definition_period = YEAR
