@@ -16,6 +16,6 @@ class ia_eitc(Variable):
     defined_for = StateCode.IA
 
     def formula(tax_unit, period, parameters):
-        federal_eitc = tax_unit("earned_income_tax_credit", period)
+        federal_eitc = tax_unit("eitc", period)
         p = parameters(period).gov.states.ia.tax.income
         return federal_eitc * p.credits.earned_income.fraction
