@@ -10,6 +10,6 @@ class il_eitc(Variable):
     reference = "https://www2.illinois.gov/rev/programs/EIC/Pages/default.aspx"
 
     def formula(tax_unit, period, parameters):
-        eitc = tax_unit("earned_income_tax_credit", period)
-        rate = parameters(period).gov.states.il.tax.income.credits.eitc.match
-        return eitc * rate
+        federal_eitc = tax_unit("eitc", period)
+        match = parameters(period).gov.states.il.tax.income.credits.eitc.match
+        return federal_eitc * match
