@@ -1,11 +1,10 @@
 from policyengine_us.model_api import *
 
 
-# TODO: apparently test is required for this, even though this is directly linked to il_personal_exemption_eligibility_status?
 class il_personal_exemption(Variable):
     value_type = float
     entity = TaxUnit
-    label = "IL personal exemption amount"
+    label = "Illinois personal exemption amount"
     unit = USD
     definition_period = YEAR
 
