@@ -4,7 +4,7 @@ from policyengine_us.model_api import *
 class in_unemployment_compensation_deduction(Variable):
     value_type = float
     entity = TaxUnit
-    label = "IN Unemployment compensation deduction"
+    label = "Indiana unemployment compensation deduction"
     unit = USD
     definition_period = YEAR
     reference = (
@@ -21,9 +21,9 @@ class in_unemployment_compensation_deduction(Variable):
         agi_reduction = p.unemployment_compensation.agi_reduction[
             filing_status
         ]
-        reduced_agi = max(0, federal_agi - agi_reduction)
+        reduced_agi = max_(0, federal_agi - agi_reduction)
         reduced_agi_haircut = p.unemployment_compensation.reduced_agi_haircut
-        in_taxable_unemployment_compensation = min(
+        in_taxable_unemployment_compensation = min_(
             (reduced_agi_haircut * reduced_agi),
             unemployment_compensation_in_federal_agi,
         )
