@@ -14,6 +14,6 @@ class ks_exemptions(Variable):
     defined_for = StateCode.KS
 
     def formula(tax_unit, period, parameters):
-        num_exemptions = tax_unit("ks_count_exemptions", period)
+        exemptions_count = tax_unit("ks_count_exemptions", period)
         p = parameters(period).gov.states.ks.tax.income.exemptions
-        return num_exemptions * p.amount
+        return exemptions_count * p.amount
