@@ -15,12 +15,16 @@ class la_income_tax_before_non_refundable_credits(Variable):
         filing_status = tax_unit("filing_status", period)
         status = filing_status.possible_values
         p = parameters(period).gov.states.la.tax.income.main
-        return select(
+        # The exemption amount is applied to the bottom tax rate and to the top tax rate
+        exemptions = tax_unit("la_exemptions", period)
+        bottom_tax_rate = p.single.rates[0]
+        exempt_income_tax = exemptions * bottom_tax_rate
+        pre_exemption_tax_amount = select(
             [
                 filing_status == status.SINGLE,
                 filing_status == status.JOINT,
                 filing_status == status.SEPARATE,
-                filing_status == status.WIDOW,
+                filing_status == status.SURVIVING_SPOUSE,
                 filing_status == status.HEAD_OF_HOUSEHOLD,
             ],
             [
@@ -31,3 +35,4 @@ class la_income_tax_before_non_refundable_credits(Variable):
                 p.head_of_household.calc(income),
             ],
         )
+        return max_(pre_exemption_tax_amount - exempt_income_tax, 0)
