@@ -3,7 +3,7 @@ from policyengine_us.model_api import *
 
 class mt_salt_deduction(Variable):
     value_type = float
-    entity = TaxUnit
+    entity = Person
     label = "Montana state and local tax deduction"
     unit = USD
     definition_period = YEAR
@@ -14,10 +14,11 @@ class mt_salt_deduction(Variable):
     )
     defined_for = StateCode.MT
 
-    def formula(tax_unit, period, parameters):
+    def formula(person, period, parameters):
+        # Not included the SALT tax, only real estate taxes
         p = parameters(period).gov.irs.deductions
-        filing_status = tax_unit("filing_status", period)
-        real_estate_tax = add(tax_unit, period, ["real_estate_taxes"])
+        filing_status = person.tax_unit("filing_status", period)
+        real_estate_tax = person("real_estate_taxes", period)
         return min_(
             real_estate_tax,
             p.itemized.salt_and_real_estate.cap[filing_status],
