@@ -21,7 +21,7 @@ class nc_ctc(Variable):
                 filing_status == status.SINGLE,
                 filing_status == status.HEAD_OF_HOUSEHOLD,
                 filing_status == status.JOINT,
-                filing_status == status.WIDOW,
+                filing_status == status.SURVIVING_SPOUSE,
                 filing_status == status.SEPARATE,
             ],
             [
