@@ -8,3 +8,6 @@ class nc_taxable_income(Variable):
     unit = USD
     definition_period = YEAR
     defined_for = StateCode.NC
+
+    adds = ["adjusted_gross_income", "nc_additions"]
+    subtracts = ["nc_deductions"]
