@@ -4,14 +4,14 @@ from policyengine_us.model_api import *
 class nd_rtrc(Variable):
     value_type = float
     entity = TaxUnit
-    label = "ND resident-tax-relief nonrefundable credit amount"
+    label = "North Dakota resident-tax-relief nonrefundable credit amount"
     unit = USD
     definition_period = YEAR
     reference = (
-        "https://www.tax.nd.gov/sites/www/files/documents/forms/form-nd-1-2021.pdf"
-        "https://www.tax.nd.gov/sites/www/files/documents/forms/2021-individual-income-tax-booklet.pdf"
-        "https://www.tax.nd.gov/sites/www/files/documents/forms/form-nd-1-2022.pdf"
-        "https://www.tax.nd.gov/sites/www/files/documents/forms/2022-individual-income-tax-booklet.pdf"
+        "https://www.tax.nd.gov/sites/www/files/documents/forms/individual/2021-iit/form-nd-1-2021.pdf#page=2"  # line 20
+        "https://www.tax.nd.gov/sites/www/files/documents/forms/individual/2021-iit/individual-income-tax-booklet-2021.pdf#page=14"
+        "https://www.tax.nd.gov/sites/www/files/documents/forms/individual/2022-iit/form-nd-1-2022.pdf#page=2"  # line 20
+        "https://www.tax.nd.gov/sites/www/files/documents/forms/individual/2022-iit/2022-individual-income-tax-booklet.pdf#page=14"
     )
     defined_for = StateCode.ND
 
