@@ -3,8 +3,8 @@ from policyengine_us.model_api import *
 
 class oh_bonus_depreciation_add_back(Variable):
     value_type = float
-    entity = TaxUnit
-    label = "OH bonus depreciation add back"
+    entity = Person
+    label = "Ohio bonus depreciation add back"
     definition_period = YEAR
     documentation = ""
     reference = ""
