@@ -10,8 +10,6 @@ class or_taxable_income(Variable):
     defined_for = StateCode.OR
 
     def formula(tax_unit, period, parameters):
-        income_after_subtractions = tax_unit(
-            "or_income_after_subtractions", period
-        )
+        or_agi = tax_unit("or_agi", period)
         deductions = tax_unit("or_deductions", period)
-        return max_(income_after_subtractions - deductions, 0)
+        return max_(or_agi - deductions, 0)
