@@ -8,6 +8,6 @@ class sc_tuition_credit_eligible(Variable):
     definition_period = YEAR
     reference = (
         "https://dor.sc.gov/forms-site/Forms/I319_2021.pdf#page=2",
-        "https://www.scstatehouse.gov/code/t12c006.php"
+        "https://www.scstatehouse.gov/code/t12c006.php",
         # South Carolina Legal Code | SECTION 12-6-3385 (B)(3)(b)
     )
