@@ -10,13 +10,7 @@ class ut_eitc(Variable):
     definition_period = YEAR
     defined_for = StateCode.UT
 
-    def formula_2022(tax_unit, period, parameters):
+    def formula(tax_unit, period, parameters):
         p = parameters(period).gov.states.ut.tax.income.credits.earned_income
         federal_eitc = tax_unit("eitc", period)
-        limiting_liability = tax_unit(
-            "ut_income_tax_before_credits", period
-        ) - tax_unit("ut_taxpayer_credit", period)
-        value = p.rate * federal_eitc
-        if not p.refundable:
-            return min_(value, limiting_liability)
-        return value
+        return p.rate * federal_eitc
