@@ -9,4 +9,4 @@ class ut_total_income(Variable):
     documentation = "Form TC-40, line 6"
     definition_period = YEAR
     defined_for = StateCode.UT
-    adds = ["adjusted_gross_income", "ut_additions_to_income"]
+    adds = ["adjusted_gross_income", "ut_additions"]
