@@ -12,7 +12,4 @@ class va_personal_exemption(Variable):
         "https://law.lis.virginia.gov/vacodefull/title58.1/chapter3/article2/"
     )
 
-    def formula(tax_unit, period, parameters):
-        p = parameters(period).gov.states.va.tax.income.exemptions
-        tax_unit_size = tax_unit("tax_unit_size", period)
-        return tax_unit_size * p.personal
+    adds = ["va_personal_exemption_person"]
