@@ -18,7 +18,7 @@ class va_federal_state_employees_subtraction(Variable):
             period
         ).gov.states.va.tax.income.subtractions.disability_income
 
-        employment_income = person("employment_income", period)
+        employment_income = person("irs_employment_income", period)
         state_or_federal_salary = person("state_or_federal_salary", period)
         subtractable_federal_state_salary = where(
             employment_income > p.amount, 0, state_or_federal_salary
