@@ -33,12 +33,11 @@ class snap_utility_allowance_type(Variable):
                 spm_unit("has_heating_cooling_expense", period),
                 lua_is_defined & (distinct_utility_bills >= 2),
                 distinct_utility_bills > 0,
-                True,
             ],
             [
                 SNAPUttilityAllowanceType.SUA,
                 SNAPUttilityAllowanceType.LUA,
                 SNAPUttilityAllowanceType.IUA,
-                SNAPUttilityAllowanceType.NONE,
             ],
+            default=SNAPUttilityAllowanceType.NONE,
         )
