@@ -9,7 +9,7 @@ class snap_child_support_deduction(Variable):
     documentation = (
         "Deduction from SNAP gross income for child support payments"
     )
-    definition_period = YEAR
+    definition_period = MONTH
     reference = "https://www.law.cornell.edu/uscode/text/7/2014#e_4"
 
     adds = ["child_support_expense"]
