@@ -18,13 +18,12 @@ class snap_excess_medical_expense_deduction(Variable):
         person = spm_unit.members
         elderly = person("is_usda_elderly", period)
         disabled = person("is_usda_disabled", period)
-        moop = person("medical_out_of_pocket_expenses", period)
+        moop = person("medical_expense", period)
         elderly_disabled_moop = spm_unit.sum(moop * (elderly | disabled))
         p = parameters(
             period
         ).gov.usda.snap.income.deductions.excess_medical_expense
-        disregard = p.disregard
-        excess = max_(elderly_disabled_moop - disregard, 0)
+        excess = max_(elderly_disabled_moop - p.disregard, 0)
         # Calculate standard medical deduction (SMD).
         state = spm_unit.household("state_code_str", period)
         standard = p.standard[state]
