@@ -9,7 +9,7 @@ class snap_child_support_gross_income_deduction(Variable):
     documentation = (
         "Deduction for child support payments when computing SNAP gross income"
     )
-    definition_period = YEAR
+    definition_period = MONTH
     reference = "https://www.law.cornell.edu/uscode/text/7/2014#e_4"
 
     def formula(spm_unit, period, parameters):
