@@ -6,3 +6,6 @@ class tax_unit_weight(Variable):
     entity = TaxUnit
     label = "Tax unit weight"
     definition_period = YEAR
+
+    def formula(tax_unit, period, parameters):
+        return tax_unit.household("household_weight", period)
