@@ -16,4 +16,8 @@ class household_income_decile(Variable):
         weighted_income = MicroSeries(
             income, weights=household_weight * count_people
         )
-        return weighted_income.decile_rank().values
+        decile = weighted_income.decile_rank().values
+        # Set negatives to -1.
+        # This avoids the bottom decile summing to a negative number,
+        # which would flip the % change in the interface.
+        return where(income < 0, -1, decile)
