@@ -23,9 +23,8 @@ class spm_unit_benefits(Variable):
             "wic",
             "free_school_meals",
             "reduced_price_school_meals",
-            "lifeline",
-            "acp",
-            "ebb",
+            "spm_unit_broadband_subsidy",
+            "spm_unit_energy_subsidy",
             "tanf",
             "high_efficiency_electric_home_rebate",
             "residential_efficiency_electrification_rebate",
